==> nextcloud-26.0.11p1.tgz: nextcloud/apps/theming/l10n/nl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "De opgegeven naam is te lang",
    "The given web address is too long" : "Het opgegeven internetadres is te lang",
    "The given web address is not a valid URL" : "Het opgegeven internetadres is geen geldige URL",
    "The given legal notice address is too long" : "Het opgegeven adres voor de juridische melding is te lang",
    "The given legal notice address is not a valid URL" : "Het opgegeven adres voor de juridische melding geen geldige URL",
    "The given privacy policy address is too long" : "Het opgegeven adres met privacybeleid is te lang",
    "The given privacy policy address is not a valid URL" : "Het opgegeven adres met privacybeleid is geen geldige URL",
    "The given slogan is too long" : "De opgegeven slagzin is te lang",
    "The given color is invalid" : "De opgegeven kleur is ongeldig",
    "Disable-user-theming should be true or false" : "Uitschakelen-gebruiker-thema's moet waar of onwaar zijn",
    "Saved" : "Opgeslagen",
    "The file was uploaded" : "Het bestand werd geüpload",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize richtlijn in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE richtlijn die is opgegeven in het HTML formulier",
    "The file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Could not write file to disk" : "Kan bestand niet opslaan",
    "A PHP extension stopped the file upload" : "Een PHP extensie heeft de upload gestopt.",
    "No file uploaded" : "Geen bestand geüpload",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Je gebruikt al een aangepast thema. Theming app opties kunnen daardoor worden overschreven.",
    "Theming" : "Uiterlijk",
    "Appearance and accessibility" : "Weergave en toegankelijkheid",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "De PHP-module \"imagick\" is niet ingeschakeld, hoewel de thema-app dat wel is. Om ervoor te zorgen dat het genereren van favicons correct werkt, moet je deze module installeren en inschakelen.",
    "Dark theme with high contrast mode" : "Donker thema met hoog contrast modus",
    "Enable dark high contrast mode" : "Donkere hoog contrast modus inschakelen",
    "Similar to the high contrast mode, but with dark colours." : "Vergelijkbaar met de hoog contrast modus, maar met donkere kleuren",
    "Dark theme" : "Donker thema",
    "Enable dark theme" : "Donker thema inschakelen",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Een donker thema om je ogen te laten rusten door het verminderen van de algehele lichtsterkte en helderheid.",
    "System default theme" : "Standaard systeemthema",
    "Enable the system default" : "Schakel het standaard systeemthema in",
    "Using the default system appearance." : "De standaard systeemweergave gebruiken",
    "Dyslexia font" : "Dyslexie-lettertype",
    "Enable dyslexia font" : "Dyslexie-lettertype inschakelen",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is een open source lettertype dat is ontwikkeld om de meest voorkomende leesfouten die worden veroorzaakt door dyslexie te voorkomen.",
    "High contrast mode" : "Hoog contrast modus",
    "Enable high contrast mode" : "Hoog contrast modus inschakelen",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Een thema met hoog contrast dat de navigatie vergemakkelijkt. De visuele kwaliteit vermindert, maar de duidelijkheid neemt toe.",
    "Light theme" : "Licht thema",
    "Enable the default light theme" : "Schakel het standaard lichte thema in",
    "The default light appearance." : "De standaard lichte weergave.",
    "Legal notice" : "Juridische bepalingen",
    "Privacy policy" : "Privacybeleid",
    "Adjust the Nextcloud theme" : "Nextcloud thema bijstellen",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Thematiseren maakt het mogelijk om uiterlijk en gevoel van je systeem en ondersteunde clients aan te passen. Dit wordt zichtbaar voor alle gebruikers.",
    "Advanced options" : "Geavanceerde opties",
    "Name" : "Naam",
    "Web link" : "Weblink",
    "a safe home for all your data" : "een veilige plek voor al je gegevens",
    "Slogan" : "Slagzin",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nieuw logo",
    "Background and login image" : "Achtergrond en aanmeld afbeelding",
    "Legal notice link" : "Link naar juridische bepalingen",
    "Privacy policy link" : "Privacybeleid link",
    "Header logo" : "Top logo",
    "Upload new header logo" : "Upload een nieuwe top afbeelding",
    "Favicon" : "Favorietenpictogram",
    "Upload new favicon" : "Upload een nieuwe favorietenpictogram",
    "User settings" : "Instellingen gebruiker",
    "Disable user theming" : "Gebruiker thema's uitschakelen",
    "Background" : "Achtergrond",
    "Customization has been disabled by your administrator" : "Maatwerk is uitgeschakeld door uw beheerder",
    "Set a custom background" : "Stel persoonlijke achtergrond in",
    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In sommige gevallen kunnen sneltoetsen interfereren met toegankelijkheidstools. Om de juiste focus op uw hulpmiddel mogelijk te maken, kunt u hier alle sneltoetsen uitschakelen. Dit zal ook alle beschikbare sneltoetsen in apps uitschakelen.",
    "Disable all keyboard shortcuts" : "Schakel alle sneltoetsen uit",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universele toegang is heel belangrijk voor ons. We volgen webstandaarden en controleren dat alles ook zonder muis en met ondersteunende software zoals schermlezers bruikbaar is. We streven om de {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 op AA-niveau te volgen, en met het hoge contrast thema zelfs op AAA-niveau.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Als je problemen tegenkomt, aarzel dan niet om deze te rapporteren op {issuetracker}onze issue tracker{linkend}. En als je betrokken wilt raken, word dan lid van {designteam}ons designteam{linkend}!",
    "Move up" : "Verplaats naar boven",
    "Move down" : "Lager zetten",
    "Custom background" : "Aangepaste achtergrond",
    "Default background" : "Standaard achtergrond",
    "Change color" : "Wijzigen kleur",
    "No background" : "Geen achtergrond",
    "Select background" : "Selecteer achtergrond",
    "Theme selection is enforced" : "Themaselectie is afgedwongen",
    "Select a custom color" : "Selecteer een aangepaste kleur",
    "Reset to default" : "Herstellen naar standaard",
    "Upload" : "Uploaden",
    "Remove background image" : "Achtergrond beeld verwijderen"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.4.tgz: nextcloud/apps/theming/l10n/nl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "De opgegeven naam is te lang",
    "The given web address is too long" : "Het opgegeven internetadres is te lang",
    "The given web address is not a valid URL" : "Het opgegeven internetadres is geen geldige URL",
    "The given legal notice address is too long" : "Het opgegeven adres voor de juridische melding is te lang",
    "The given legal notice address is not a valid URL" : "Het opgegeven adres voor de juridische melding geen geldige URL",
    "The given privacy policy address is too long" : "Het opgegeven adres met privacybeleid is te lang",
    "The given privacy policy address is not a valid URL" : "Het opgegeven adres met privacybeleid is geen geldige URL",
    "The given slogan is too long" : "De opgegeven slagzin is te lang",
    "The given color is invalid" : "De opgegeven kleur is ongeldig",
    "Disable-user-theming should be true or false" : "Uitschakelen-gebruiker-thema's moet waar of onwaar zijn",
    "Saved" : "Opgeslagen",
    "The file was uploaded" : "Het bestand werd geüpload",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Het geüploade bestand overschrijdt de upload_max_filesize richtlijn in php.ini:",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Het bestand overschrijdt de MAX_FILE_SIZE richtlijn die is opgegeven in het HTML formulier",
    "The file was only partially uploaded" : "Het bestand is slechts gedeeltelijk geüpload",
    "No file was uploaded" : "Er is geen bestand geüpload",
    "Missing a temporary folder" : "Er ontbreekt een tijdelijke map",
    "Could not write file to disk" : "Kan bestand niet opslaan",
    "A PHP extension stopped the file upload" : "Een PHP extensie heeft de upload gestopt.",
    "No file uploaded" : "Geen bestand geüpload",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Je gebruikt al een aangepast thema. Theming app opties kunnen daardoor worden overschreven.",
    "Theming" : "Uiterlijk",
    "Appearance and accessibility" : "Weergave en toegankelijkheid",
    "Dark theme with high contrast mode" : "Donker thema met hoog contrast modus",
    "Enable dark high contrast mode" : "Donkere hoog contrast modus inschakelen",
    "Similar to the high contrast mode, but with dark colours." : "Vergelijkbaar met de hoog contrast modus, maar met donkere kleuren",
    "Dark theme" : "Donker thema",
    "Enable dark theme" : "Donker thema inschakelen",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Een donker thema om je ogen te laten rusten door het verminderen van de algehele lichtsterkte en helderheid.",
    "System default theme" : "Standaard systeemthema",
    "Enable the system default" : "Schakel het standaard systeemthema in",
    "Using the default system appearance." : "De standaard systeemweergave gebruiken",
    "Dyslexia font" : "Dyslexie-lettertype",
    "Enable dyslexia font" : "Dyslexie-lettertype inschakelen",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic is een open source lettertype dat is ontwikkeld om de meest voorkomende leesfouten die worden veroorzaakt door dyslexie te voorkomen.",
    "High contrast mode" : "Hoog contrast modus",
    "Enable high contrast mode" : "Hoog contrast modus inschakelen",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Een thema met hoog contrast dat de navigatie vergemakkelijkt. De visuele kwaliteit vermindert, maar de duidelijkheid neemt toe.",
    "Light theme" : "Licht thema",
    "Enable the default light theme" : "Schakel het standaard lichte thema in",
    "The default light appearance." : "De standaard lichte weergave.",
    "Legal notice" : "Juridische bepalingen",
    "Privacy policy" : "Privacybeleid",
    "Adjust the Nextcloud theme" : "Nextcloud thema bijstellen",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Thematiseren maakt het mogelijk om uiterlijk en gevoel van je systeem en ondersteunde clients aan te passen. Dit wordt zichtbaar voor alle gebruikers.",
    "Advanced options" : "Geavanceerde opties",
    "Name" : "Naam",
    "Web link" : "Weblink",
    "a safe home for all your data" : "een veilige plek voor al je gegevens",
    "Slogan" : "Slagzin",
    "Color" : "Kleur",
    "Logo" : "Logo",
    "Upload new logo" : "Upload nieuw logo",
    "Background and login image" : "Achtergrond en aanmeld afbeelding",
    "Legal notice link" : "Link naar juridische bepalingen",
    "Privacy policy link" : "Privacybeleid link",
    "Header logo" : "Top logo",
    "Upload new header logo" : "Upload een nieuwe top afbeelding",
    "Favicon" : "Favorietenpictogram",
    "Upload new favicon" : "Upload een nieuwe favorietenpictogram",
    "User settings" : "Instellingen gebruiker",
    "Disable user theming" : "Gebruiker thema's uitschakelen",
    "Background" : "Achtergrond",
    "Customization has been disabled by your administrator" : "Maatwerk is uitgeschakeld door uw beheerder",
    "Set a custom background" : "Stel persoonlijke achtergrond in",
    "Keyboard shortcuts" : "Toetsenbord sneltoetsen",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In sommige gevallen kunnen sneltoetsen interfereren met toegankelijkheidstools. Om de juiste focus op uw hulpmiddel mogelijk te maken, kunt u hier alle sneltoetsen uitschakelen. Dit zal ook alle beschikbare sneltoetsen in apps uitschakelen.",
    "Disable all keyboard shortcuts" : "Schakel alle sneltoetsen uit",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universele toegang is heel belangrijk voor ons. We volgen webstandaarden en controleren dat alles ook zonder muis en met ondersteunende software zoals schermlezers bruikbaar is. We streven om de {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 op AA-niveau te volgen, en met het hoge contrast thema zelfs op AAA-niveau.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Als je problemen tegenkomt, aarzel dan niet om deze te rapporteren op {issuetracker}onze issue tracker{linkend}. En als je betrokken wilt raken, word dan lid van {designteam}ons designteam{linkend}!",
    "Move up" : "Verplaats naar boven",
    "Move down" : "Lager zetten",
    "Custom background" : "Aangepaste achtergrond",
    "Default background" : "Standaard achtergrond",
    "Change color" : "Wijzigen kleur",
    "No background" : "Geen achtergrond",
    "Select background" : "Selecteer achtergrond",
    "Theme selection is enforced" : "Themaselectie is afgedwongen",
    "Select a custom color" : "Selecteer een aangepaste kleur",
    "Reset to default" : "Herstellen naar standaard",
    "Upload" : "Uploaden",
    "Remove background image" : "Achtergrond beeld verwijderen",
    "Loading preview…" : "Laden voorbeeld...",
    "Admin" : "Beheer",
    "Error uploading the file" : "Fout bij uploaden van het bestand",
    "Name cannot be empty" : "Naam mag niet leeg zijn",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "In sommige gevallen grijpen sneltoetsen in op de werking van toegankelijkheidstools. Om correct op uw hulpmiddel te kunnen concentreren, kunt u hier alle sneltoetsen uitschakelen. Dit zal ook alle beschikbare sneltoetsen in apps uitschakelen.",
    "Pick from Files" : "Kies uit Bestanden",
    "Default image" : "Standaard afbeelding",
    "Custom color" : "Kleur op maat",
    "Plain background" : "Kale achtergrond",
    "Insert from {productName}" : "Invoegen vanuit {productName}",
    "Open documentation" : "Documentatie openen",
    "https://…" : "https://…",
    "Upload new login background" : "Uploaden nieuwe inlog achtergrond",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Hoewel u uw instantie kunt selecteren en aanpassen, kunnen gebruikers hun achtergrond en kleuren wijzigen. Als je jouw maatwerk wilt afdwingen, kun je dit vakje aanvinken.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installeer de Imagemagick PHP extensie met ondersteuning voor SVG afbeeldingen om automatisch favicons te genereren op basis van het geuploade logo en kleur."
},
"nplurals=2; plural=(n != 1);");
